Quickstart
==========

Tomni is made to make image analysis and computer vision easier.
It is created and used by `CytoSMART <https://cytosmart.com/>`_.
The functions are detailed in :doc:`apidocs`.


Usage
-----

Use tomni to get image dimension of an array

.. code::

   >>> from tomni import img_dim
   >>> print(img_dim(image))
